@@ -1,13 +1,13 @@
 import os
 
-__version__ = '0.90'
+__version__ = '0.91'
 FW_INSTALL_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 
 # These imports allow a much simpler import of core Fireworks functionality.
-# E.g., you can now do "from fireworks import FireWork", instead of from
-# "fireworks.core.firework import FireWork".
-from fireworks.core.firework import FireTaskBase, FireWork, Launch, Workflow, \
-    FWAction
+# E.g., you can now do "from fireworks import Firework", instead of from
+# "fireworks.core.firework import Firework".
+from fireworks.core.firework import FireTaskBase, Firework, Launch, Workflow, \
+    FWAction, FireWork
 from fireworks.core.fworker import FWorker
 from fireworks.core.launchpad import LaunchPad
 from fireworks.utilities.fw_utilities import explicit_serialize
