@@ -1,8 +1,11 @@
+# coding: utf-8
+
+from __future__ import unicode_literals, division
+
 """
 TODO: Modify module doc.
 """
 
-from __future__ import division
 
 __author__ = "Shyue Ping Ong"
 __copyright__ = "Copyright 2012, The Materials Project"
@@ -21,4 +24,4 @@ class DummyTask(FireTaskBase):
 
     def run_task(self, fw_spec):
         data = fw_spec["_fw_env"].get("hello", "hello")
-        return FWAction(stored_data={"data": data})
\ No newline at end of file
+        return FWAction(stored_data={"data": data})
