@@ -1,3 +1,7 @@
+# coding: utf-8
+
+from __future__ import unicode_literals
+
 """
 This module implements a CommonAdaptor that supports standard PBS and SGE
 queues.
