@@ -1,3 +1,7 @@
+# coding: utf-8
+
+from __future__ import unicode_literals
+
 """
 Support for simple timers, with CSV output.
 
@@ -243,4 +247,4 @@ class NullTimer(Timer):
         return type_ is None  # re-raises exception, if there was one
 
     def __len__(self):
-        return 0
\ No newline at end of file
+        return 0
